@@ -3,9 +3,9 @@ define(
 {
 	"HKD_displayName": "dollar de Hong Kong",
 	"CHF_displayName": "franc suisse",
-	"JPY_symbol": "¥JP",
+	"JPY_symbol": "JPY",
 	"CAD_displayName": "dollar canadien",
-	"HKD_symbol": "$HK",
+	"HKD_symbol": "HKD",
 	"CNY_displayName": "yuan renminbi chinois",
 	"USD_symbol": "$US",
 	"AUD_displayName": "dollar australien",
@@ -13,7 +13,7 @@ define(
 	"CAD_symbol": "$CA",
 	"USD_displayName": "dollar des États-Unis",
 	"EUR_symbol": "€",
-	"CNY_symbol": "¥CN",
+	"CNY_symbol": "CNY",
 	"GBP_displayName": "livre sterling",
 	"GBP_symbol": "£GB",
 	"AUD_symbol": "$AU",
