@@ -13,7 +13,6 @@ define([
 "dojo/dom-geometry",
 "dojo/dom-construct",
 "dojo/query",
-"dojox/html/metrics",
 "dojo/i18n",
 "./ViewBase",
 "dojo/text!./templates/MatrixView.html",
@@ -34,7 +33,6 @@ function(
 	domGeometry,
 	domConstruct,
 	query,
-	metrics,
 	i18n,
 	ViewBase,
 	template,
